==> xcsoar-7.22.tar.xz: xcsoar-7.22/README.md <==
# <img src="./Data/graphics/logo.svg" width="5%" alt="XCSoar Logo"> XCSoar

[![.github/workflows/build-android.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-android.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-android.yml)
[![.github/workflows/build-kobo.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-kobo.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-kobo.yml)
[![.github/workflows/build-win64.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-win64.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-win64.yml)
[![.github/workflows/build-unix.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-unix.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-unix.yml)
[![.github/workflows/build-docs.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-docs.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-docs.yml)

XCSoar is a tactical glide computer for Android, Linux, Mac OS X,
and Windows.

This file is aimed at developers. Developers should read the manual which can
be found on the [XCSoar home page](https://xcsoar.org/discover/manual.html).

Users can refer to the Users' Manual which, for the latest release, can be
downloaded via the [XCSoar home page](https://xcsoar.org/discover/manual.html).

## Getting the source

The XCSoar source code is managed with [git](http://git-scm.com/). It can be
downloaded with the following command:

```bash
git clone --recursive git://github.com/XCSoar/XCSoar
```

To update your repository, type:

```bash
git pull
```

For more information, please refer to the git documentation.

## Compiling from source

Please read the current [Developer's
Manual](https://xcsoar.readthedocs.io/en/latest/build.html) for
detailed build instructions.

## Submitting patches

Patches may be submitted using the Developers' mail list or GitHub. Refer to
chapter 3 of the current Developers' Manual for details of how to write and
submit patches upstream.

==> xcsoar-7.23.tar.xz: xcsoar-7.23/README.md <==
# <img src="./Data/graphics/logo.svg" width="5%" alt="XCSoar Logo"> XCSoar

[![.github/workflows/build-android.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-android.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-android.yml)
[![.github/workflows/build-kobo.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-kobo.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-kobo.yml)
[![.github/workflows/build-win64.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-win64.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-win64.yml)
[![.github/workflows/build-unix.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-unix.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-unix.yml)
[![.github/workflows/build-docs.yml](https://github.com/XCSoar/XCSoar/actions/workflows/build-docs.yml/badge.svg)](https://github.com/XCSoar/XCSoar/actions/workflows/build-docs.yml)

XCSoar is a tactical glide computer for Android, Linux, Mac OS X,
and Windows.

This file is aimed at developers.  Developers should [read the
developer manual](https://xcsoar.readthedocs.io/en/latest/).

Users can refer to the Users' Manual which, for the latest release, can be
downloaded via the [XCSoar home page](https://xcsoar.org/discover/manual.html).

## Getting the source

The XCSoar source code is managed with [git](http://git-scm.com/). It can be
downloaded with the following command:

```bash
git clone --recursive git://github.com/XCSoar/XCSoar
```

To update your repository, type:

```bash
git pull
```

For more information, please refer to the git documentation.

## Compiling from source

Please read the current [Developer's
Manual](https://xcsoar.readthedocs.io/en/latest/build.html) for
detailed build instructions.

## Submitting patches

Patches may be submitted using the Developers' mail list or GitHub. Refer to
chapter 3 of the current Developers' Manual for details of how to write and
submit patches upstream.
